==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/HorizontalRangeCategorySeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { RangeCategorySeries } from "./RangeCategorySeries";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-angular-core";
import { NumericYAxis } from "./NumericYAxis";
import { Axis } from "./Axis";
import { Point_$type, runOn, typeCast, markType, markDep } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { RangeValueList } from "./RangeValueList";
import { ScalerParams } from "./ScalerParams";
import { CategoryXAxis } from "./CategoryXAxis";
import { DataLegendSeriesValueInfo } from "igniteui-angular-core";
import { DataLegendSeriesContext } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
/**
 * @hidden
 */
var HorizontalRangeCategorySeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HorizontalRangeCategorySeries, _super);
    function HorizontalRangeCategorySeries() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalRangeCategorySeries.prototype.fetchXAxis = function () {
        return this.xAxis;
    };
    HorizontalRangeCategorySeries.prototype.fetchYAxis = function () {
        return this.yAxis;
    };
    HorizontalRangeCategorySeries.prototype.kz = function () {
        _super.prototype.kz.call(this);
        this.xAxis = null;
        this.yAxis = null;
    };
    HorizontalRangeCategorySeries.prototype.ah = function (a) {
        var b = this.aj(this.rw(), this.rx.f, this.sx(this.b1), this.sy(this.b1), this.px(a), true);
        if (b == null) {
            return null;
        }
        var c = b[0];
        var d = b[1];
        var e = new Array(1);
        var f = new Array(2);
        f[0] = { $type: Point_$type, x: c[0], y: c[2] };
        f[1] = { $type: Point_$type, x: d[0], y: d[2] };
        e[0] = f;
        return e;
    };
    HorizontalRangeCategorySeries.prototype.ai = function (a) {
        var b = this.aj(this.rw(), this.rx.f, this.sx(this.b1), this.sy(this.b1), this.px(a), true);
        if (b == null) {
            return null;
        }
        var c = b[0];
        var d = b[1];
        var e = new Array(1);
        var f = new Array(2);
        f[0] = { $type: Point_$type, x: c[0], y: c[1] };
        f[1] = { $type: Point_$type, x: d[0], y: d[1] };
        e[0] = f;
        return e;
    };
    HorizontalRangeCategorySeries.prototype.get_ee = function () {
        return true;
    };
    HorizontalRangeCategorySeries.prototype.bq = function () {
        if (this.br == 0) {
            return 1;
        }
        else {
            return _super.prototype.bq.call(this);
        }
    };
    HorizontalRangeCategorySeries.prototype.getOffsetValue = function () {
        return this.RangeFramePreparer.r(this.xAxis, this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1));
    };
    HorizontalRangeCategorySeries.prototype.getCategoryWidth = function () {
        return this.xAxis.getCategorySize(this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1));
    };
    HorizontalRangeCategorySeries.prototype.hm = function (a, b) {
        return this.hn(a, b, this.xAxis, runOn(this, this.sv), new RangeValueList(this.highColumn, this.lowColumn));
    };
    HorizontalRangeCategorySeries.prototype.ho = function (a, b) {
        return this.hp(a, b, this.xAxis, runOn(this, this.sv), new RangeValueList(this.highColumn, this.lowColumn));
    };
    HorizontalRangeCategorySeries.prototype.f7 = function (a, b, c, d, e) {
        if (c == null) {
            return Number.POSITIVE_INFINITY;
        }
        var f = this.xAxis.le;
        return this.f8(a, b, this.xAxis, d, e, f, runOn(this, this.sv));
    };
    HorizontalRangeCategorySeries.prototype.gn = function (a, b, c) {
        if (this.ce == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.b1);
        var e = new ScalerParams(0, this.ce.ta, this.b1.bu, this.xAxis.cg, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.ce.ta, this.b1.bu, d);
        return this.gp(new RangeValueList(this.highColumn, this.lowColumn), a, this.xAxis, e, f, runOn(this, this.sv), b, c);
    };
    HorizontalRangeCategorySeries.prototype.gl = function (a, b, c) {
        if (this.ce == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.b1);
        var e = new ScalerParams(0, this.ce.ta, this.b1.bu, this.xAxis.cg, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.ce.ta, this.b1.bu, d);
        return this.gp(this.lowColumn, a, this.xAxis, e, f, runOn(this, this.sv), b, c);
    };
    HorizontalRangeCategorySeries.prototype.gj = function (a, b, c) {
        if (this.ce == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.b1);
        var e = new ScalerParams(0, this.ce.ta, this.b1.bu, this.xAxis.cg, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.ce.ta, this.b1.bu, d);
        return this.gp(this.highColumn, a, this.xAxis, e, f, runOn(this, this.sv), b, c);
    };
    HorizontalRangeCategorySeries.prototype.po = function (a, b, c) {
        var _this = this;
        return this.pu(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1)), this.yAxis, this.xAxis, runOn(this, this.gj), function (d, e) { return _this.hp(d, e, _this.xAxis, runOn(_this, _this.sv), _this.highColumn); }, function (d, e) { return _this.hn(d, e, _this.xAxis, runOn(_this, _this.sv), _this.highColumn); });
    };
    HorizontalRangeCategorySeries.prototype.pq = function (a, b, c) {
        var _this = this;
        return this.pu(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1)), this.yAxis, this.xAxis, runOn(this, this.gl), function (d, e) { return _this.hp(d, e, _this.xAxis, runOn(_this, _this.sv), _this.lowColumn); }, function (d, e) { return _this.hn(d, e, _this.xAxis, runOn(_this, _this.sv), _this.lowColumn); });
    };
    HorizontalRangeCategorySeries.prototype.ps = function (a, b, c) {
        return this.pu(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1)), this.yAxis, this.xAxis, null, null, null);
    };
    HorizontalRangeCategorySeries.prototype.sr = function () {
        return this.yAxis != null && this.yAxis.c0();
    };
    HorizontalRangeCategorySeries.prototype.l9 = function (a, b, c, d) {
        _super.prototype.l9.call(this, a, b, c, d);
        switch (b) {
            case HorizontalRangeCategorySeries.$$p[4]:
                this.k6(typeCast(Axis.$, c));
                this.me(typeCast(Axis.$, d));
                this.r6.cr.g(this.fx);
                this.mn(false);
                this.lu();
                break;
            case HorizontalRangeCategorySeries.$$p[5]:
                this.k6(typeCast(Axis.$, c));
                this.me(typeCast(Axis.$, d));
                this.r6.cr.g(this.fx);
                this.sr();
                this.mn(false);
                this.lu();
                break;
        }
    };
    HorizontalRangeCategorySeries.prototype.t5 = function (a) {
        if (typeCast(NumericYAxis.$, a) !== null) {
            return true;
        }
        return false;
    };
    HorizontalRangeCategorySeries.prototype.t4 = function (a) {
        if (typeCast(CategoryXAxis.$, a) !== null || a.cd) {
            return true;
        }
        return false;
    };
    HorizontalRangeCategorySeries.prototype.getDataLegendSeriesContextAt = function (a, b) {
        var c = { $type: Point_$type, x: a, y: b };
        var d = this.gl(c, false, false);
        var e = this.gj(c, false, false);
        var f = new DataLegendSeriesValueInfo();
        f.a = 1;
        f.l = e > d ? d : e;
        f.p = "Low";
        f.q = this.tx != null ? this.tx : "Low";
        f.r = this.ua != null ? this.ua : "L:";
        f.s = this.uc != null ? this.uc : "";
        var g = new DataLegendSeriesValueInfo();
        g.a = 2;
        g.l = e > d ? e : d;
        g.p = "High";
        g.q = this.tu != null ? this.tu : "High";
        g.r = this.t6 != null ? this.t6 : "H:";
        g.s = this.t8 != null ? this.t8 : "";
        var h = new DataLegendSeriesValueInfo();
        h.a = 7;
        h.l = Math.abs(g.l - f.l);
        h.p = "Range";
        h.q = "Range";
        h.r = "R:";
        h.k = true;
        var i = new DataLegendSeriesValueInfo();
        i.a = 6;
        i.l = f.l + (h.l / 2);
        i.p = "Average";
        i.q = "Average";
        i.r = "A:";
        i.k = true;
        var j = new DataLegendSeriesContext();
        j.f = ((function () {
            var $ret = new List$1(DataLegendSeriesValueInfo.$, 0);
            $ret.add(g);
            $ret.add(f);
            $ret.add(h);
            $ret.add(i);
            return $ret;
        })());
        j.b = this.aw();
        return j;
    };
    Object.defineProperty(HorizontalRangeCategorySeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.ss;
        },
        enumerable: false,
        configurable: true
    });
    HorizontalRangeCategorySeries.$t = markType(HorizontalRangeCategorySeries, 'HorizontalRangeCategorySeries', RangeCategorySeries.$);
    HorizontalRangeCategorySeries.$$p = markDep(DependencyProperty, PropertyMetadata, HorizontalRangeCategorySeries, 'raisePropertyChanged', ['HighMemberAsLegendLabel:t6:ug', [2, null], 'HighMemberAsLegendUnit:t8:uh', [2, null], 'LowMemberAsLegendLabel:ua:ui', [2, null], 'LowMemberAsLegendUnit:uc:uj', [2, null], 'XAxis::uk', [CategoryAxisBase.$, null], 'YAxis::ul', [NumericYAxis.$, null]]);
    return HorizontalRangeCategorySeries;
}(RangeCategorySeries));
export { HorizontalRangeCategorySeries };

==> igniteui-angular-charts-17.0.0-beta.0.tgz: package/esm5/lib/HorizontalRangeCategorySeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { RangeCategorySeries } from "./RangeCategorySeries";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-angular-core";
import { NumericYAxis } from "./NumericYAxis";
import { Axis } from "./Axis";
import { Point_$type, runOn, typeCast, markType, markDep } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { RangeValueList } from "./RangeValueList";
import { ScalerParams } from "./ScalerParams";
import { CategoryXAxis } from "./CategoryXAxis";
import { DataLegendSeriesValueInfo } from "igniteui-angular-core";
import { DataLegendSeriesContext } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
/**
 * @hidden
 */
var HorizontalRangeCategorySeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HorizontalRangeCategorySeries, _super);
    function HorizontalRangeCategorySeries() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalRangeCategorySeries.prototype.fetchXAxis = function () {
        return this.xAxis;
    };
    HorizontalRangeCategorySeries.prototype.fetchYAxis = function () {
        return this.yAxis;
    };
    HorizontalRangeCategorySeries.prototype.kz = function () {
        _super.prototype.kz.call(this);
        this.xAxis = null;
        this.yAxis = null;
    };
    HorizontalRangeCategorySeries.prototype.ah = function (a) {
        var b = this.aj(this.rw(), this.rx.f, this.sx(this.b1), this.sy(this.b1), this.px(a), true);
        if (b == null) {
            return null;
        }
        var c = b[0];
        var d = b[1];
        var e = new Array(1);
        var f = new Array(2);
        f[0] = { $type: Point_$type, x: c[0], y: c[2] };
        f[1] = { $type: Point_$type, x: d[0], y: d[2] };
        e[0] = f;
        return e;
    };
    HorizontalRangeCategorySeries.prototype.ai = function (a) {
        var b = this.aj(this.rw(), this.rx.f, this.sx(this.b1), this.sy(this.b1), this.px(a), true);
        if (b == null) {
            return null;
        }
        var c = b[0];
        var d = b[1];
        var e = new Array(1);
        var f = new Array(2);
        f[0] = { $type: Point_$type, x: c[0], y: c[1] };
        f[1] = { $type: Point_$type, x: d[0], y: d[1] };
        e[0] = f;
        return e;
    };
    HorizontalRangeCategorySeries.prototype.get_ee = function () {
        return true;
    };
    HorizontalRangeCategorySeries.prototype.bq = function () {
        if (this.br == 0) {
            return 1;
        }
        else {
            return _super.prototype.bq.call(this);
        }
    };
    HorizontalRangeCategorySeries.prototype.getOffsetValue = function () {
        return this.RangeFramePreparer.r(this.xAxis, this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1));
    };
    HorizontalRangeCategorySeries.prototype.getCategoryWidth = function () {
        return this.xAxis.getCategorySize(this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1));
    };
    HorizontalRangeCategorySeries.prototype.hm = function (a, b) {
        return this.hn(a, b, this.xAxis, runOn(this, this.sv), new RangeValueList(this.highColumn, this.lowColumn));
    };
    HorizontalRangeCategorySeries.prototype.ho = function (a, b) {
        return this.hp(a, b, this.xAxis, runOn(this, this.sv), new RangeValueList(this.highColumn, this.lowColumn));
    };
    HorizontalRangeCategorySeries.prototype.f7 = function (a, b, c, d, e) {
        if (c == null) {
            return Number.POSITIVE_INFINITY;
        }
        var f = this.xAxis.lf;
        return this.f8(a, b, this.xAxis, d, e, f, runOn(this, this.sv));
    };
    HorizontalRangeCategorySeries.prototype.gn = function (a, b, c) {
        if (this.ce == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.b1);
        var e = new ScalerParams(0, this.ce.tj, this.b1.bu, this.xAxis.ch, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.ce.tj, this.b1.bu, d);
        return this.gp(new RangeValueList(this.highColumn, this.lowColumn), a, this.xAxis, e, f, runOn(this, this.sv), b, c);
    };
    HorizontalRangeCategorySeries.prototype.gl = function (a, b, c) {
        if (this.ce == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.b1);
        var e = new ScalerParams(0, this.ce.tj, this.b1.bu, this.xAxis.ch, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.ce.tj, this.b1.bu, d);
        return this.gp(this.lowColumn, a, this.xAxis, e, f, runOn(this, this.sv), b, c);
    };
    HorizontalRangeCategorySeries.prototype.gj = function (a, b, c) {
        if (this.ce == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.b1);
        var e = new ScalerParams(0, this.ce.tj, this.b1.bu, this.xAxis.ch, d);
        var f = this.RangeFramePreparer.r(this.xAxis, this.ce.tj, this.b1.bu, d);
        return this.gp(this.highColumn, a, this.xAxis, e, f, runOn(this, this.sv), b, c);
    };
    HorizontalRangeCategorySeries.prototype.po = function (a, b, c) {
        var _this = this;
        return this.pu(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1)), this.yAxis, this.xAxis, runOn(this, this.gj), function (d, e) { return _this.hp(d, e, _this.xAxis, runOn(_this, _this.sv), _this.highColumn); }, function (d, e) { return _this.hn(d, e, _this.xAxis, runOn(_this, _this.sv), _this.highColumn); });
    };
    HorizontalRangeCategorySeries.prototype.pq = function (a, b, c) {
        var _this = this;
        return this.pu(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1)), this.yAxis, this.xAxis, runOn(this, this.gl), function (d, e) { return _this.hp(d, e, _this.xAxis, runOn(_this, _this.sv), _this.lowColumn); }, function (d, e) { return _this.hn(d, e, _this.xAxis, runOn(_this, _this.sv), _this.lowColumn); });
    };
    HorizontalRangeCategorySeries.prototype.ps = function (a, b, c) {
        return this.pu(a, b, c, this.RangeFramePreparer.r(this.xAxis, this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1)), this.yAxis, this.xAxis, null, null, null);
    };
    HorizontalRangeCategorySeries.prototype.sr = function () {
        return this.yAxis != null && this.yAxis.c1();
    };
    HorizontalRangeCategorySeries.prototype.l9 = function (a, b, c, d) {
        _super.prototype.l9.call(this, a, b, c, d);
        switch (b) {
            case HorizontalRangeCategorySeries.$$p[4]:
                this.k6(typeCast(Axis.$, c));
                this.me(typeCast(Axis.$, d));
                this.r6.cr.g(this.fx);
                this.mn(false);
                this.lu();
                break;
            case HorizontalRangeCategorySeries.$$p[5]:
                this.k6(typeCast(Axis.$, c));
                this.me(typeCast(Axis.$, d));
                this.r6.cr.g(this.fx);
                this.sr();
                this.mn(false);
                this.lu();
                break;
        }
    };
    HorizontalRangeCategorySeries.prototype.t5 = function (a) {
        if (typeCast(NumericYAxis.$, a) !== null) {
            return true;
        }
        return false;
    };
    HorizontalRangeCategorySeries.prototype.t4 = function (a) {
        if (typeCast(CategoryXAxis.$, a) !== null || a.ce) {
            return true;
        }
        return false;
    };
    HorizontalRangeCategorySeries.prototype.getDataLegendSeriesContextAt = function (a, b) {
        var c = { $type: Point_$type, x: a, y: b };
        var d = this.gl(c, false, false);
        var e = this.gj(c, false, false);
        var f = new DataLegendSeriesValueInfo();
        f.a = 1;
        f.l = e > d ? d : e;
        f.p = "Low";
        f.q = this.tx != null ? this.tx : "Low";
        f.r = this.ua != null ? this.ua : "L:";
        f.s = this.uc != null ? this.uc : "";
        var g = new DataLegendSeriesValueInfo();
        g.a = 2;
        g.l = e > d ? e : d;
        g.p = "High";
        g.q = this.tu != null ? this.tu : "High";
        g.r = this.t6 != null ? this.t6 : "H:";
        g.s = this.t8 != null ? this.t8 : "";
        var h = new DataLegendSeriesValueInfo();
        h.a = 7;
        h.l = Math.abs(g.l - f.l);
        h.p = "Range";
        h.q = "Range";
        h.r = "R:";
        h.k = true;
        var i = new DataLegendSeriesValueInfo();
        i.a = 6;
        i.l = f.l + (h.l / 2);
        i.p = "Average";
        i.q = "Average";
        i.r = "A:";
        i.k = true;
        var j = new DataLegendSeriesContext();
        j.f = ((function () {
            var $ret = new List$1(DataLegendSeriesValueInfo.$, 0);
            $ret.add(g);
            $ret.add(f);
            $ret.add(h);
            $ret.add(i);
            return $ret;
        })());
        j.b = this.aw();
        return j;
    };
    Object.defineProperty(HorizontalRangeCategorySeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.ss;
        },
        enumerable: false,
        configurable: true
    });
    HorizontalRangeCategorySeries.$t = markType(HorizontalRangeCategorySeries, 'HorizontalRangeCategorySeries', RangeCategorySeries.$);
    HorizontalRangeCategorySeries.$$p = markDep(DependencyProperty, PropertyMetadata, HorizontalRangeCategorySeries, 'raisePropertyChanged', ['HighMemberAsLegendLabel:t6:ug', [2, null], 'HighMemberAsLegendUnit:t8:uh', [2, null], 'LowMemberAsLegendLabel:ua:ui', [2, null], 'LowMemberAsLegendUnit:uc:uj', [2, null], 'XAxis::uk', [CategoryAxisBase.$, null], 'YAxis::ul', [NumericYAxis.$, null]]);
    return HorizontalRangeCategorySeries;
}(RangeCategorySeries));
export { HorizontalRangeCategorySeries };
